@@ -10,7 +10,9 @@ from . views import (carousel, carousel_item, carousel_item_link,
                      publication_related,
                      website, webpath, webpath_pub_context,
                      page, page_block, page_carousel, page_link,
-                     page_media, page_menu, page_publication,
+                     page_media, page_media_collection,
+                     page_menu, page_publication,
+                     page_heading, page_heading_localization,
                      page_related, page_localization, page_template,
                      template_block, menu, menu_item, locks)
 
@@ -41,12 +43,16 @@ m_prefix = f'{eb_prefix}/medias'
 urlpatterns += path(f'{m_prefix}/', media.MediaList.as_view(), name='medias'),
 urlpatterns += path(f'{m_prefix}/<int:pk>/', media.MediaView.as_view(), name='media'),
 urlpatterns += path(f'{m_prefix}/form/', media.MediaFormView.as_view(), name='media-form'),
+urlpatterns += path(f'{m_prefix}/options/', media.MediaOptionList.as_view(), name='media-options'),
+urlpatterns += path(f'{m_prefix}/options/<int:pk>/', media.MediaOptionView.as_view(), name='media-option'),
 
 # media collections
 mc_prefix = f'{eb_prefix}/media-collections'
 urlpatterns += path(f'{mc_prefix}/', media_collection.MediaCollectionList.as_view(), name='media-collections'),
 urlpatterns += path(f'{mc_prefix}/<int:pk>/', media_collection.MediaCollectionView.as_view(), name='media-collection'),
 urlpatterns += path(f'{mc_prefix}/form/', media_collection.MediaCollectionFormView.as_view(), name='media-collection-form'),
+urlpatterns += path(f'{mc_prefix}/options/', media_collection.MediaCollectionOptionList.as_view(), name='media-collection-options'),
+urlpatterns += path(f'{mc_prefix}/options/<int:pk>/', media_collection.MediaCollectionOptionView.as_view(), name='media-collection-option'),
 
 # media collection items
 mci_prefix = f'{mc_prefix}/<int:collection_id>/items'
@@ -99,6 +105,9 @@ w_prefix = f'{eb_prefix}/sites/<int:site_id>/webpaths'
 urlpatterns += path(f'{w_prefix}/', webpath.EditorWebsiteWebpathList.as_view(), name='editorial-board-site-webpaths'),
 urlpatterns += path(f'{w_prefix}/<int:pk>/', webpath.EditorWebsiteWebpathView.as_view(), name='editorial-board-site-webpath'),
 urlpatterns += path(f'{w_prefix}/form/', webpath.WebpathFormView.as_view(), name='editorial-board-site-webpath-form'),
+urlpatterns += path(f'{eb_prefix}/sites/webpaths/options/', webpath.WebpathAllOptionList.as_view(), name='webpath-all-options'),
+urlpatterns += path(f'{w_prefix}/options/', webpath.WebpathOptionList.as_view(), name='webpath-options'),
+urlpatterns += path(f'{w_prefix}/options/<int:pk>/', webpath.WebpathOptionView.as_view(), name='webpath-option'),
 
 # pages
 pa_prefix = f'{w_prefix}/<int:webpath_id>/pages'
@@ -119,6 +128,18 @@ urlpatterns += path(f'{pab_prefix}/', page_block.PageBlockList.as_view(), name='
 urlpatterns += path(f'{pab_prefix}/<int:pk>/', page_block.PageBlockView.as_view(), name='editorial-board-site-webpath-page-block'),
 urlpatterns += path(f'{pab_prefix}/form/', page_block.PageBlockFormView.as_view(), name='editorial-board-site-webpath-page-block-form'),
 
+# page headings
+pah_prefix = f'{pa_prefix}/<int:page_id>/headings'
+urlpatterns += path(f'{pah_prefix}/', page_heading.PageHeadingList.as_view(), name='editorial-board-site-webpath-page-headings'),
+urlpatterns += path(f'{pah_prefix}/<int:pk>/', page_heading.PageHeadingView.as_view(), name='editorial-board-site-webpath-page-heading'),
+urlpatterns += path(f'{pah_prefix}/form/', page_heading.PageHeadingFormView.as_view(), name='editorial-board-site-webpath-page-heading-form'),
+
+# page heading localizations
+pahl_prefix = f'{pa_prefix}/<int:page_id>/headings/<int:heading_id>/localizations'
+urlpatterns += path(f'{pahl_prefix}/', page_heading_localization.PageHeadingLocalizationList.as_view(), name='editorial-board-site-webpath-page-heading-localizations'),
+urlpatterns += path(f'{pahl_prefix}/<int:pk>/', page_heading_localization.PageHeadingLocalizationView.as_view(), name='editorial-board-site-webpath-page-heading-localization'),
+urlpatterns += path(f'{pahl_prefix}/form/', page_heading_localization.PageHeadingLocalizationFormView.as_view(), name='editorial-board-site-webpath-page-heading-localization-form'),
+
 # page links
 pali_prefix = f'{pa_prefix}/<int:page_id>/links'
 urlpatterns += path(f'{pali_prefix}/', page_link.PageLinkList.as_view(), name='editorial-board-site-webpath-page-links'),
@@ -145,6 +166,12 @@ urlpatterns += path(f'{pamed_prefix}/', page_media.PageMediaList.as_view(), name
 urlpatterns += path(f'{pamed_prefix}/<int:pk>/', page_media.PageMediaView.as_view(), name='editorial-board-site-webpath-page-media'),
 urlpatterns += path(f'{pamed_prefix}/form/', page_media.PageMediaFormView.as_view(), name='editorial-board-site-webpath-page-media-form'),
 
+# page media collections
+pamecol_prefix = f'{pa_prefix}/<int:page_id>/media-collections'
+urlpatterns += path(f'{pamecol_prefix}/', page_media_collection.PageMediaCollectionList.as_view(), name='editorial-board-site-webpath-page-media-collections'),
+urlpatterns += path(f'{pamecol_prefix}/<int:pk>/', page_media_collection.PageMediaCollectionView.as_view(), name='editorial-board-site-webpath-page-media-collection'),
+urlpatterns += path(f'{pamecol_prefix}/form/', page_media_collection.PageMediaCollectionFormView.as_view(), name='editorial-board-site-webpath-page-media-collection-form'),
+
 # page menus
 pamen_prefix = f'{pa_prefix}/<int:page_id>/menus'
 urlpatterns += path(f'{pamen_prefix}/', page_menu.PageMenuList.as_view(), name='editorial-board-site-webpath-page-menus'),
@@ -183,6 +210,8 @@ urlpatterns += path(f'{pu_prefix}/<int:pk>/', publication.PublicationView.as_vie
 urlpatterns += path(f'{pu_prefix}/<int:pk>/change-status/', publication.PublicationChangeStateView.as_view(),
                     name='editorial-board-publication-change-status'),
 urlpatterns += path(f'{pu_prefix}/form/', publication.PublicationFormView.as_view(), name='editorial-board-publication-form'),
+urlpatterns += path(f'{pu_prefix}/options/', publication.PublicationOptionList.as_view(), name='editorial-board-publications-options'),
+urlpatterns += path(f'{pu_prefix}/options/<int:pk>/', publication.PublicationOptionView.as_view(), name='editorial-board-publications-option'),
 
 # publication attachments
 pua_prefix = f'{pu_prefix}/<int:publication_id>/attachments'
@@ -258,4 +287,4 @@ urlpatterns += path(f'{eb_prefix}/locks/<int:content_type_id>/<int:object_id>/',
 urlpatterns += path(f'{eb_prefix}/locks/<int:content_type_id>/<int:object_id>/<int:pk>/',
                     locks.ObjectUserLocksView.as_view(), name='editorial-board-lock-delete'),
 urlpatterns += path(f'{eb_prefix}/users/form/', webpath_pub_context.EditorialBoardLockUserFormView.as_view(), name='users-form'),
-urlpatterns += path(f'{eb_prefix}/redis-lock/<int:content_type_id>/<int:object_id>/', locks.RedisLockView.as_view(), name='editorial-board-r'),
+urlpatterns += path(f'{eb_prefix}/redis-lock/<int:content_type_id>/<int:object_id>/', locks.RedisLockView.as_view(), name='editorial-board-redis-lock'),
