@@ -13,8 +13,10 @@ class PagePublicationList(PageRelatedObjectList):
     """
     """
     description = ""
-    search_fields = ['publication__title', 'publication__subheading'
-                     'publication__content']
+    search_fields = ['publication__name','publication__title',
+                     'publication__subheading', 'publication__content']
+    ordering_fields = ['id', 'publication__name', 'publication__title',
+                       'publication__subheading', 'order', 'is_active']
     serializer_class = PagePublicationSerializer
 
     def get_queryset(self):
