@@ -10,7 +10,7 @@ from cms.contexts.models_abstract import AbstractLockable
 
 from cms.carousels.models import Carousel
 
-from cms.medias.models import Media
+from cms.medias.models import Media, MediaCollection
 from cms.medias.validators import *
 
 from cms.menus.models import NavigationBar
@@ -174,8 +174,7 @@ class Page(TimeStampedModel, ActivableModel, AbstractDraftable,
         for i in chain(blocks_list, template_blocks_list):
             order_pk.add(i)
         ordered = list(order_pk)
-        ordered.sort(key=lambda x:x[1])
-
+        ordered.sort(key=lambda x:x[0][0])
         _blocks = []
         # add a on-the-fly section attribute on the blocks ...
         for item in ordered:
@@ -225,6 +224,15 @@ class Page(TimeStampedModel, ActivableModel, AbstractDraftable,
             order_by('order')
         return self._medias
 
+    def get_media_collections(self):
+        if getattr(self, '_media_collections', None): # pragma: no cover
+            return self._media_collections
+        self._media_collections = PageMediaCollection.objects.filter(page=self,
+                                                                     is_active=True,
+                                                                     collection__is_active=True).\
+            order_by('order')
+        return self._media_collections
+
     def get_menus(self):
         if getattr(self, '_menus', None):
             return self._menus
@@ -241,6 +249,14 @@ class Page(TimeStampedModel, ActivableModel, AbstractDraftable,
             order_by('order')
         return self._links
 
+    def get_headings(self):
+        if getattr(self, '_headings', None): # pragma: no cover
+            return self._headings
+        self._headings = PageHeading.objects.filter(page=self,
+                                                    is_active=True).\
+            order_by('order')
+        return self._headings
+
     def delete(self, *args, **kwargs):
         PageRelated.objects.filter(related_page=self).delete()
         super(self.__class__, self).delete(*args, **kwargs)
@@ -372,6 +388,7 @@ class PageBlock(ActivableModel, SectionAbstractModel, SortableModel,
     page = models.ForeignKey(Page, null=False, blank=False,
                              on_delete=models.CASCADE)
     block = models.ForeignKey(TemplateBlock, null=False, blank=False,
+                              limit_choices_to={'is_active': True},
                               on_delete=models.CASCADE)
 
     class Meta:
@@ -429,3 +446,58 @@ class PagePublication(TimeStampedModel, SortableModel, ActivableModel,
 
     def __str__(self):
         return '{} {}'.format(self.page, self.publication)
+
+
+class PageMediaCollection(SectionAbstractModel, ActivableModel, SortableModel,
+                          TimeStampedModel, CreatedModifiedBy):
+    page = models.ForeignKey(Page, on_delete=models.CASCADE)
+    collection = models.ForeignKey(MediaCollection,
+                                   on_delete=models.CASCADE)
+
+    class Meta:
+        verbose_name_plural = _("Page Media Collection")
+
+    def __str__(self):
+        return '{} {}'.format(self.page, self.collection)
+
+
+class PageHeading(SectionAbstractModel, ActivableModel, SortableModel,
+                  TimeStampedModel, CreatedModifiedBy):
+    page = models.ForeignKey(Page, null=False, blank=False,
+                             on_delete=models.CASCADE)
+    title = models.CharField(max_length=256, null=False, blank=False)
+    description = models.TextField(null=True, blank=True)
+
+    class Meta:
+        verbose_name_plural = _("Page Headings")
+
+    def translate_as(self, lang):
+        """
+        returns translation if available
+        """
+        trans = PageHeadingLocalization.objects.filter(heading=self,
+                                                       language=lang,
+                                                       is_active=True).first()
+        if trans:
+            self.title = trans.title
+            self.description = trans.description
+
+    def __str__(self):
+        return '{} {}'.format(self.page, self.title)
+
+
+class PageHeadingLocalization(ActivableModel,
+                              TimeStampedModel, SortableModel,
+                              CreatedModifiedBy):
+    heading = models.ForeignKey(PageHeading, on_delete=models.CASCADE)
+    language = models.CharField(choices=settings.LANGUAGES,
+                                max_length=12, null=False,blank=False,
+                                default='en')
+    title = models.CharField(max_length=256, null=False, blank=False)
+    description = models.TextField(null=True, blank=True)
+
+    class Meta:
+        verbose_name_plural = _("Page Heading Localizations")
+
+    def __str__(self):
+        return '{} {}'.format(self.heading, self.language)
