@@ -11,11 +11,8 @@ logger = logging.getLogger(__name__)
 
 @admin.register(Publication)
 class PublicationAdmin(AbstractCreatedModifiedBy):
-    search_fields = ('title', 'slug',)
-    # list_display = ('title', 'slug', 'date_start', 'date_end', 'is_active',)
-    list_display = ('title', 'slug', 'is_active',)
-    # list_filter = ('state', 'is_active',
-    # 'created', 'modified', 'date_start', 'date_end')
+    search_fields = ('name', 'title', 'slug',)
+    list_display = ('name', 'title', 'slug', 'is_active',)
     list_filter = ('is_active', 'created', 'modified')
     inlines = (PublicationLocalizationInline,
                PublicationContextInline,
@@ -34,7 +31,7 @@ class PublicationAdmin(AbstractCreatedModifiedBy):
 
 @admin.register(PublicationLocalization)
 class PublicationLocalizationAdmin(AbstractCreatedModifiedBy):
-    search_fields = ('publication__title', 'publication__slug')
+    search_fields = ('publication__name', 'publication__title', 'publication__slug')
     list_display = ('publication', 'language', 'is_active',)
     # list_filter = ('publication__state', 'is_active',
     # 'created', 'modified', 'language')
